aboutsummaryrefslogtreecommitdiffstats
path: root/jitterbuf.h
diff options
context:
space:
mode:
authorrussell <russell@f38db490-d61c-443f-a65b-d21fe96a405b>2005-05-12 19:01:03 +0000
committerrussell <russell@f38db490-d61c-443f-a65b-d21fe96a405b>2005-05-12 19:01:03 +0000
commit0a934da882569311c32ab9b2d840f3e3147f6b46 (patch)
tree984bf00ec82c3410df07892932ef4b4f2f227c44 /jitterbuf.h
parente5bd600fd7a8edcbfb1a38a115b7b9e9c3a7d097 (diff)
fixes for the new jitter buffer (bug #4249)
git-svn-id: http://svn.digium.com/svn/asterisk/trunk@5639 f38db490-d61c-443f-a65b-d21fe96a405b
Diffstat (limited to 'jitterbuf.h')
-rwxr-xr-xjitterbuf.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/jitterbuf.h b/jitterbuf.h
index 224751630..839120290 100755
--- a/jitterbuf.h
+++ b/jitterbuf.h
@@ -63,7 +63,7 @@ typedef struct jb_info {
long current; /* the present jitterbuffer adjustment */
long target; /* the target jitterbuffer adjustment */
long losspct; /* recent lost frame percentage (* 1000) */
- long last_voice_ts; /* the last ts that was read from the jb - in receiver's time */
+ long next_voice_ts; /* the ts of the next frame to be read from the jb - in receiver's time */
long last_voice_ms; /* the duration of the last voice frame */
long silence_begin_ts; /* the time of the last CNG frame, when in silence */
long last_adjustment; /* the time of the last adjustment */
@@ -115,10 +115,10 @@ int jb_put(jitterbuf *jb, void *data, int type, long ms, long ts, long now);
* JB_OK: You've got frame!
* JB_DROP: Here's an audio frame you should just drop. Ask me again for this time..
* JB_NOFRAME: There's no frame scheduled for this time.
* JB_INTERP: Please interpolate an audio frame for this time (either we need to grow, or there was a lost frame
* JB_EMPTY: The jb is empty.
*/
-int jb_get(jitterbuf *jb, jb_frame *frame, long now);
+int jb_get(jitterbuf *jb, jb_frame *frame, long now, long interpl);
/* unconditionally get frames from jitterbuf until empty */
int jb_getall(jitterbuf *jb, jb_frame *frameout);
@@ -115,10 +115,10 @@ int jb_put(jitterbuf *jb, void *data, int type, long ms, long ts, long now);
* JB_DROP: Here's an audio frame you should just drop. Ask me again for this time..
* JB_NOFRAME: There's no frame scheduled for this time.
- * JB_INTERP: Please interpolate an audio frame for this time (either we need to grow, or there was a lost frame
+ * JB_INTERP: Please interpolate an interpl-length frame for this time (either we need to grow, or there was a lost frame)
* JB_EMPTY: The jb is empty.
*/